Index: /anuga_work/production/pt_hedland_2008/project_250m.py
===================================================================
--- /anuga_work/production/pt_hedland_2008/project_250m.py	(revision 6014)
+++ /anuga_work/production/pt_hedland_2008/project_250m.py	(revision 6015)
@@ -38,6 +38,6 @@
 # Note, the user needs to set up the directory system accordingly
 state = 'western_australia'
-scenario_name = 'perth'
-scenario = 'perth_tsunami_scenario'
+scenario_name = 'pt_hedland'
+scenario = 'pt_hedland_tsunami_scenario_2008'
 
 # Model specific parameters. One or all can be changed each time the
@@ -51,5 +51,5 @@
 finaltime=80000         # final time for simulation
 
-interior_mesh = 'all' # Can have 'all' or 'none' for Phase 2 study
+interior_mesh = 'none' # Can have 'all' or 'none' for Phase 2 study
 
 setup='final'  # Final can be replaced with trial or basic.
@@ -84,19 +84,19 @@
 #------------------------------------------------------------------------------
 
 # elevation data used in build_perth.py
 # onshore data: format ascii grid with accompanying projection file
 onshore_name = 'grid_250m_2005' 
 
 # gauges - used in get_timeseries.py
-gauge_name = 'perth.csv'
+gauge_name = 'pt_hedland.csv'
 gauge_name2 = 'thinned_MGA50.csv'
 
 # BOUNDING POLYGON - used in build_boundary.py and run_perth.py respectively
 # NOTE: when files are put together the points must be in sequence - for ease go clockwise!
 # Check the run_perth.py for boundary_tags
 # thinned ordering file from Hazard Map: format is index,latitude,longitude (with title)
-order_filename = 'thinned_boundary_ordering.txt'
+order_filename = 'thinned_boundary_ordering.csv'
 #landward bounding points
-landward = 'landward_bounding_polygon.txt'
+landward = 'landward_bounding_polygon.csv'
 
 #------------------------------------------------------------------------------
@@ -105,5 +105,5 @@
 # Output filename for elevation
 # this is a combination of all the data (utilisied in build_boundary)
-combined_name ='perth_combined_elevation_250m'
+combined_name ='pt_hedland_combined_elevation_250m'
 
 #------------------------------------------------------------------------------
@@ -132,5 +132,5 @@
 combined_dir_name = topographies_dir + combined_name
 
 # where the mesh sits (this is created during the run_perth.py)
 meshes_dir_name = meshes_dir + scenario_name+ interior_mesh +'.msh'
 
@@ -138,5 +138,5 @@
 order_filename_dir = boundaries_dir + order_filename
 
 # where the landward points of boundary extent sit (this is used within run_perth.py)
 landward_dir = boundaries_dir + landward
 
@@ -146,6 +146,6 @@
 
 # where the directory of the output filename sits
-output_build_time_dir = output_dir+build_time+dir_comment+sep   #used for build_perth.py
-output_run_time_dir = output_dir+run_time+dir_comment+sep       #used for run_perth.py
+output_build_time_dir = output_dir+build_time+dir_comment+sep   #used for build_pt_hedland.py
+output_run_time_dir = output_dir+run_time+dir_comment+sep       #used for run_pt_hedland.py
 output_run_time_dir_name = output_run_time_dir + scenario_name  #Used by post processing
 
@@ -159,5 +159,8 @@
 
 #Land, to set the initial stage/water to be offcoast only
-poly_mainland = read_polygon(polygons_dir+'initial_condition.csv')
+poly_mainland = read_polygon(polygons_dir+'initial_conditions_mainland.csv')
+
+#Ocean
+poly_ocean = read_polygon(polygons_dir+'initial_conditions_ocean.csv')
 
 # Initial bounding polygon for data clipping 
@@ -165,45 +168,15 @@
 res_poly_all = 100000*res_factor
 
-# Area of Interest 1 (Fremantle)
-poly_aoi1 = read_polygon(polygons_dir+'CBD_coastal.csv')
+# Area of Interest 1 (pt_hedland)
+poly_aoi1 = read_polygon(polygons_dir+'area_of_interest.csv')
 res_aoi1 = 500*res_factor
 
-# Area of Interest 2 (Rockingham)
-poly_aoi2 = read_polygon(polygons_dir+'rockingham_penguin.csv')
-res_aoi2 = 500*res_factor
-
-# Area of Interest 2 (garden Island)
-poly_aoi2a = read_polygon(polygons_dir+'garden.csv')
-res_aoi2a= 500*res_factor
-
-# Area of Interest 3 (geordie bay - record of tsunami impact)
-poly_aoi3 = read_polygon(polygons_dir+'geordie_bay.csv')
-res_aoi3 = 500*res_factor
-
-# Area of Interest 4 (sorrento - record of tsunami impact)
-poly_aoi4 = read_polygon(polygons_dir+'sorrento_gauge.csv')
-res_aoi4 = 500*res_factor
-
-# Area of Significance 1 (Garden Island and sand bank infront of Rockingham)
-poly_aos1 = read_polygon(polygons_dir+'garden_rockingham.csv')
+# Area of Significance 1 (pt_hedland)
+poly_aos1 = read_polygon(polygons_dir+'area_of_significance.csv')
 res_aos1 = 1000*res_factor
 
-# Area of Significance 2 (incorporate coastline of rottnest)
-poly_aos2 = read_polygon(polygons_dir+'rottnest_external.csv')
-res_aos2 = 1000*res_factor
-
-# Refined areas
-# Polygon designed to incorporate dredged area from Fremantle to
-# Rockingham as the steep incline was making the elevation go to 0
-poly_aos3 = read_polygon(polygons_dir+'DredgeArea.csv')
-res_aos3 = 1000*res_factor
-
 # Shallow water 1
-poly_sw1 = read_polygon(polygons_dir+'internal_h20mORd3km.csv')
+poly_sw1 = read_polygon(polygons_dir+'shallow_water.csv')
 res_sw1 = 25000*res_factor
-
-# Deep water (land of Rottnest, ANUGA does not do donuts!)
-poly_dw1 = read_polygon(polygons_dir+'rottnest_internal.csv')
-res_dw1 = 100000*res_factor
 
 # Combined all regions, must check that all are included!
@@ -211,9 +184,7 @@
 if interior_mesh =='all':
     print'Mesh = all'
-    interior_regions = [[poly_aoi1,res_aoi1],[poly_aoi2,res_aoi2]
-                     ,[poly_aoi2a,res_aoi2a],[poly_aoi3,res_aoi3]
-                     ,[poly_aoi4,res_aoi4],[poly_aos1,res_aos1]
-                     ,[poly_aos2,res_aos2],[poly_aos3,res_aos3]
-                     ,[poly_sw1,res_sw1], [poly_dw1,res_dw1]]
+    interior_regions = [[poly_aoi1,res_aoi1],[poly_aos1,res_aos1]
+                     ,[poly_sw1,res_sw1]]
+
 if interior_mesh =='none': 
     print'Mesh = none'
@@ -223,31 +194,2 @@
 print 'min estimated number of triangles', trigs_min
    
-#------------------------------------------------------------------------------
-# Clipping regions for export to asc and regions for clipping data
-# Final inundation maps should only be created in regions of the finest mesh
-#------------------------------------------------------------------------------
-
-#Geordie Bay extract ascii grid
-xminGeordie = 358000
-xmaxGeordie = 362000
-yminGeordie = 6458500
-ymaxGeordie = 6461000
-
-#Sorrento extract ascii grid
-xminSorrento = 379000
-xmaxSorrento = 382500
-yminSorrento = 6477000
-ymaxSorrento = 6480000
-
-#Fremantle extract ascii grid
-xminFremantle = 376000
-xmaxFremantle = 388000
-yminFremantle = 6449000
-ymaxFremantle = 6461000
-
-#Rockingham extract ascii grid
-xminRockingham = 373500
-xmaxRockingham = 385500
-yminRockingham = 6424000
-ymaxRockingham = 6433000
-
@@ -84,19 +84,19 @@
 #------------------------------------------------------------------------------
 
-# elevation data used in build_perth.py
+# elevation data used in build_pt_hedland.py
 # onshore data: format ascii grid with accompanying projection file
 onshore_name = 'grid_250m_2005' 
@@ -84,19 +84,19 @@
 gauge_name2 = 'thinned_MGA50.csv'
 
-# BOUNDING POLYGON - used in build_boundary.py and run_perth.py respectively
+# BOUNDING POLYGON - used in build_boundary.py and run_pt_hedland.py respectively
 # NOTE: when files are put together the points must be in sequence - for ease go clockwise!
@@ -84,19 +84,19 @@
 # NOTE: when files are put together the points must be in sequence - for ease go clockwise!
-# Check the run_perth.py for boundary_tags
+# Check the run_pt_hedland.py for boundary_tags
 # thinned ordering file from Hazard Map: format is index,latitude,longitude (with title)
@@ -132,5 +132,5 @@
 combined_dir_name = topographies_dir + combined_name
 
-# where the mesh sits (this is created during the run_perth.py)
+# where the mesh sits (this is created during the run_pt_hedland.py)
 meshes_dir_name = meshes_dir + scenario_name+ interior_mesh +'.msh'
 
@@ -138,5 +138,5 @@
 order_filename_dir = boundaries_dir + order_filename
 
-# where the landward points of boundary extent sit (this is used within run_perth.py)
+# where the landward points of boundary extent sit (this is used within run_pt_hedland.py)
 landward_dir = boundaries_dir + landward
 
